Ext.define('JooOverrides.Ext.Action', {
  override: 'Ext.Action',
  // patch constructor to avoid Actions being copied when their Component is added to a Container:
  constructor:  function(config) {
    if (!config) {
      config = {};
    }
    if (arguments.length === 0) {
      arguments = [config];
    }
    config.baseAction = this; // self-reference, so that button references me, not my copy!
    this.callParent(arguments);
    this.initConfig(config);
  },
  initConfig: function(config) {
    this.callParent(arguments);
    // remove xclass that may have been applied to the action, so that it is not applied to the component:
    delete this.xclass;
    return this;
  },
  beforeInitConfig: function() {
    // prevent setters from being used during initConfig():
    return false;
  },
  // patch for Actions being added to a Component via config's baseAction:
  addComponent: function(component) {
    component.setDisabled(this.isDisabled());
    component.setHidden(this.isHidden());
    return this.callParent(arguments);
  },
  /**
   * Sets the tooltip to be displayed by all components configured by this Action.
   * @param {String} tooltip The tooltip to display
   */
  setTooltip : function(tooltip){
    this.initialConfig.tooltip = tooltip;
    this.callEach('setTooltip', [tooltip]);
  },

  /**
   * Gets the tooltip currently displayed by all components configured by this Action.
   */
  getTooltip : function(){
    return this.initialConfig.tooltip;
  }

});
